#
# spec file for package SwayNotificationCenter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global alt_pkg_name swaync

Name:           SwayNotificationCenter
Version:        0.11.0
Release:        1.1
Summary:        A simple GTK notification daemon
License:        GPL-3.0-only
URL:            https://github.com/ErikReider/%{name}
Provides:       %{alt_pkg_name} = %{version}-%{release}
Source0:        %{name}-%{version}.tar.gz
Requires:       gvfs
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-layer-shell-devel
BuildRequires:  meson >= 0.51.0
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  scdoc
BuildRequires:  vala >= 0.56
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.8.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libhandy-1) >= 1.8.0
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(systemd)

%description
A simple notification daemon with a GTK gui for notifications and the control center

%package bash-completion
Summary:        Bash completion for %{name}
Provides:       %{alt_pkg_name}-bash-completion = %{version}-%{release}
Supplements:    (%{name} and bash-completion)
Requires:       %{name} = %{version}-%{release}
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}

%package zsh-completion
Summary:        Zsh completion for %{name}
Provides:       %{alt_pkg_name}-zsh-completion = %{version}-%{release}
Supplements:    (%{name} and zsh)
Requires:       %{name} = %{version}-%{release}
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}

%package fish-completion
Summary:        Fish completion for %{name}
Provides:       %{alt_pkg_name}-fish-completion = %{version}-%{release}
Supplements:    (%{name} and fish)
Requires:       %{name} = %{version}-%{release}
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%files
%license COPYING
%doc README.md
%dir %{_sysconfdir}/xdg/swaync
%config %{_sysconfdir}/xdg/swaync/config.json
%config %{_sysconfdir}/xdg/swaync/configSchema.json
%config %{_sysconfdir}/xdg/swaync/style.css
%{_bindir}/swaync
%{_bindir}/swaync-client
%{_userunitdir}/swaync.service
%{_datadir}/dbus-1/services/org.erikreider.swaync.service
%{_datadir}/glib-2.0/schemas/org.erikreider.swaync.gschema.xml
%{_mandir}/man1/swaync-client.1%{?ext_man}
%{_mandir}/man1/swaync.1%{?ext_man}
%{_mandir}/man5/swaync.5%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/swaync
%{_datadir}/bash-completion/completions/swaync-client

%files zsh-completion
%{_datadir}/zsh/site-functions/_swaync
%{_datadir}/zsh/site-functions/_swaync-client

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/swaync-client.fish
%{_datadir}/fish/vendor_completions.d/swaync.fish

%changelog
* Tue Apr  8 2025 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.11.0:
  - Updated meson build instructions
  - Fixed sources annotation
  - block signal handlers in toggle button when updating state
  - Fix invalid data types in configSchema.json
  - Add MPRIS background blur for app icons
  - Close notification with middle mouse button
  - Mpris blacklist support
  - Add a way to change No Notifications text
  - Implemented xdg-activation logic
  - Fix json parsing error in config.json
  - Fixed image-path not being considered as theme icon
  - Fixed swaync-client --close-all not closing the actual noti layer window
  - Vertically center the summary/title when the notification body is empty
  - Always unescape image and app icon paths
  - Run script commands with "/bin/sh -c ..."
  - Added layer-shell-cover-screen option to fix animations in Hyprland
  - Pass hints as environment to scripts
  - Invoke action from swaync-client (implements #437)
  - fix: no convert upper case for the first character
  - Removed MPRIS widget side fade
  - Body img markup: fixed img URIs and single quotes not supported
* Fri May 31 2024 Dawid Respondek <nyslay@gmail.com>
- Update to version 0.10.1:
  * Fix brightness slider choppiness
  * Fixed BOTTOM aligned notifications in CC not compensating for fade properly
  * Fix default mpris icon size
* Mon Feb 12 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.10.0:
  * Allow empty name for actions
  * Update i3status-rs Example format syntax for 0.31.0
  * corrected misspellings of the word "notification"
  * Added "relative-timestamps" config to switch between "25 minutes ago" and "2023-06-25T20:05:27-07"
  * Add meson_option to build without PulseAudio Widget
  * Add show-per-app-label for volume
  * Fixed CC list navigation skipping a notification
  * Simplified script and base_widget command execution
  * Test parsing markup without any hacks before using said hacks
  * Remove notification replace flicker
  * Added config option to set cc exclusive zone
  * allow 8 digits in 2fa code regex
  * flush stdout after subscription events
  * Add toggle button
  * Fix togglebutton in menu dropdown
  * Add notification hint to bypass dnd/inhibition
  * Grouped notifications
  * [New Dependency: sassc] Move to SCSS from regular CSS
  * Add border-radius property to notification images
  * Add MPRIS player background blur
  * Bumped version requirements for libhandy and gtk-layer-shell
  * Fix text color on light theme
  * Add control center visibility class
  - Style changes
    A few style changes were made that might break some existing configs.
    The project also moved to use SCSS.
  - New dependencies:
  * gvfs
  * granite
  * sassc
  * gtk-layer-shell (added explicitly)
  - Split out bash, zsh and fish shell completions into dedicated packages
* Mon May 29 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.9.0:
  * Menu animation
  * Hide visible notifications when activating dnd
  * Use rounding to prevent incorrect backlight percentage calculation
  * Per app volume control
  * Fix backlight & KB brightness sliders
  * Fixed mpDris2 mpris issues
  * Preserve config object item order
  * Add positonY center for notifications and CC
  * Added ability to toggle parsing of notification 2fa codes
  * Added ability to choose wether layer-shell should be used or not
  * Added control-center layer config option
  * Add inline replies to notifications
* Fri Feb 24 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.8.0:
  * a bunch of typo fixes
  * Action scripts
  * Add Override urgency to config
  * Bump minimal meson version to 0.59.0, replace 'get_pkgconfig_variable'
  * Add ControllsWidget
  * Audio slider
  * Add Notification placeholder in Control Center
  * Add ControlCenter positioning config option
  * Add Notification Action to copy body security codes to clipboard
  * Add "desktop-entry" as option to scripts
  * Add Brightness slider widget
  * [Feature] Add ability to inhibit notifications through DBus
- Add new dependencies: libgee, libpulse
- Remove changesgenerate service as upstream publishes a better changelog
* Mon Nov 28 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.7.3:
  * Fixed segfault when reloading config
  * Adds MPRIS widget arrows when multiple players are detected
  * Fix not being able to interact with CC without first click
  * Fix MPRIS image scaling when display is scaled
  * Add cssPriority to config
  * Add option to configure control center layer
  * feat: transient notification visibility
  * Add client flags to turn dnd on/off
  * Add /usr/local/etc/xdg/swaync/ as default fallback path for config and CSS files
* Mon Sep 26 2022 Danilo Spinella <danilo.spinella@suse.com>
- Remove full source URL since it's downloaded by _service
* Mon Sep 26 2022 filippo.bonazzi@suse.com
- Update to version 0.7.2:
  * Bumped version to v0.7.2
  * Removed all references to `RegexCompileFlags.JAVASCRIPT_COMPAT` due to deprecation
  * Fixed GLib2.74.0 causing a segfault. Fixes: #164
  * Fix typo (#166)
  * Adding instructions for installation on Fedora Silverblue and other rpm-ostree Fedora variants. (#161)
  * Bumped PKGBUILD-git pkgver
  * Bumped PKGBUILD sha256 sums
* Fri Sep 16 2022 mcepl@suse.com
- Update to version 0.7.1:
  * Bumped application version to 0.7.1
  * Updated rpkg spec
  * Bumped version to 0.7.1
  * Fixed fedora build issue
  * Updated sha256 for pkgbuild
  * Bumped version to 0.7.0
  * Fix typo (#160)
  * Removed all unnecessary GLib namespace prefixes
  * Removed all unnecessary GLib namespace prefixes
  * All notification urgencies can now use 0 as timeout to not expire (#158)
  * Mpris Media Player widget (#157)
  * Updated README with info about supported WMs
  * Fixes #152
  * Fixed Control Center sometimes dismissing when clicking inside of CC
  * Customize and reorder widgets in Control Center (#150)
  * Separate arch and ubuntu GH Actions into their own files. Fixes #151
  * Updated Ubuntu docker file to use 22.04 LTS
  * Fixed Config and Style not handling custom home-relative paths
  * Fixed typo in README
  * Updated the COPR link to the new official repo
  * CI: Add Fedora builds (#144) (#148)
  * Fixed styling notification summary not working correctly. Fixes #143
  * Issue #141: Waybar subscription missed opportunity (#142)
  * Add missing build dependency and installed files in rpmbuild spec file (#140)
  * Fixed click to close Control Center not working on some WMs (#139)
  * Fix gschema not being compiled on install (#138)
  * Removed depends versions from PKGBUILD
  * Updated Git PKGBUILD with correct pkgver format
  * Updated PKGBUILD checksums for v0.6.3
* Thu Sep 15 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.7.1:
  - Fixed building on Fedora
- Upgrade to 0.7.0:
  - Fix gschema not being compiled on install by @ErikReider in
    [#138]
  - Fixed click to close Control Center not working on some WMs
    by @ErikReider in #139
  - Add missing build dependency and installed files in rpmbuild
    spec file by @fantognazza in #140
  - Issue #141: Waybar subscription missed opportunity by
    @carlosV2 in #142
  - Customize and reorder widgets in Control Center by
    @ErikReider in #150
  - Mpris widget by @ErikReider in #157
  - All notification urgency timeouts can now be 0 to disable
    expiration by @ErikReider in #158
  - Fix typo by @asas1asas200 in #160
* Wed Jul 13 2022 Michael Vetter <mvetter@suse.com>
- Remove SwayNotificationCenter-0.6.3.tar.gz since
  SwayNotificationCenter-0.6.3.obscpio is enough
* Tue Jul 12 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Package also glib-2.0 schema
* Tue Jul 12 2022 filippo.bonazzi@suse.com
- Update to version 0.6.3:
  * Bumped version to v0.6.3
  * Fixed bug where replacing notifitions aren't visible
  * Updated Pkgbuild checksums
  * Bumped version to 0.6.2
  * Fixed nasty hover bug after first notification
  * Updated style.css documentation
  * Replaced state cacher with gsettings
  * [Feature] Click outside Control Center to close (#133)
  * Fixed notification trying to set icon from invalid .desktop file
  * Renamed all notiWindow.* files to notificationWindow.*
* Mon Jul 11 2022 Otto Hollmann <otto.hollmann@suse.com>
- Fix build in i586
* Wed Jun  8 2022 Matej Cepl <mcepl@suse.com>
- Package also README.md and license. It is hard to read README
  (referred to in --help), when it is not provided.
- Fix build on 32bit architectures.
* Fri May 27 2022 Danilo Spinella <danilo.spinella@suse.com>
- Initial packaging of version 0.6.1
